@@ -105,7 +105,7 @@ hesiod_search(mnt_map *m, char *map, char *key, char **pval, time_t *tp)
   if (key[0] == '.')
     return ENOENT;
 
-  sprintf(hes_key, "%s.%s", key, map + HES_PREFLEN);
+  xsnprintf(hes_key, sizeof(hes_key), "%s.%s", key, map + HES_PREFLEN);
 
   /*
    * Call the resolver
