@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: info_nis.c,v 1.6.2.6 2005/01/03 20:56:12 ezk Exp $
+ * File: am-utils/amd/info_nis.c
  *
  */
 
@@ -107,9 +106,7 @@ determine_nis_domain(void)
   }
   if (!*default_domain) {
     nis_not_running = 1;
-#ifdef DEBUG
     plog(XLOG_WARNING, "NIS domain name is not set.  NIS ignored.");
-#endif /* DEBUG */
     return ENOENT;
   }
   gopt.nis_domain = strdup(default_domain);
@@ -144,12 +141,8 @@ callback(int status, char *key, int kl, char *val, int vl, char *data)
       /* check what went wrong */
       int e = ypprot_err(status);
 
-#ifdef DEBUG
       plog(XLOG_ERROR, "yp enumeration of %s: %s, status=%d, e=%d",
 	   ncdp->ncd_map, yperr_string(e), status, e);
-#else /* not DEBUG */
-      plog(XLOG_ERROR, "yp enumeration of %s: %s", ncdp->ncd_map, yperr_string(e));
-#endif /* not DEBUG */
     }
     return TRUE;
   }
@@ -350,9 +343,7 @@ nis_init(mnt_map *m, char *map, time_t *tp)
     /* NIS server found */
     has_yp_order = 1;
     *tp = (time_t) order;
-#ifdef DEBUG
     dlog("NIS master for %s@%s has order %lu", map, gopt.nis_domain, (unsigned long) order);
-#endif /* DEBUG */
     break;
   case YPERR_YPERR:
     /* NIS+ server found ! */
@@ -361,9 +352,7 @@ nis_init(mnt_map *m, char *map, time_t *tp)
     if (yp_master(gopt.nis_domain, map, &master)) {
       return ENOENT;
     } else {
-#ifdef DEBUG
       dlog("NIS master for %s@%s is a NIS+ server", map, gopt.nis_domain);
-#endif /* DEBUG */
       /* Use fake timestamps */
       *tp = time(NULL);
     }
@@ -442,11 +431,9 @@ am_yp_all(char *indomain, char *inmap, struct ypall_callback *incallback)
 		&outvallen);
     XFREE(outkey_old);
   } while (!i);
-#ifdef DEBUG
   if (i) {
     dlog("yp_next() returned error: %s\n", yperr_string(i));
   }
-#endif /* DEBUG */
   if (i == YPERR_NOMORE)
     return 0;
   return i;
