@@ -900,7 +900,7 @@ unmount_mp(am_node *mp)
     time_t last = mp->am_parent->am_attr.ns_u.ns_attr_u.na_mtime.nt_seconds;
     clocktime(&mp->am_parent->am_attr.ns_u.ns_attr_u.na_mtime);
     /* defensive programming... can't we assert the above condition? */
-    if (last == mp->am_parent->am_attr.ns_u.ns_attr_u.na_mtime.nt_seconds)
+    if (last == (time_t) mp->am_parent->am_attr.ns_u.ns_attr_u.na_mtime.nt_seconds)
       mp->am_parent->am_attr.ns_u.ns_attr_u.na_mtime.nt_seconds++;
   }
 #endif /* not MNT2_NFS_OPT_SYMTTL */
