@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: ops_cdfs.c,v 1.4.2.6 2005/01/03 20:56:12 ezk Exp $
+ * File: am-utils/amd/ops_cdfs.c
  *
  */
 
@@ -54,8 +53,8 @@
 
 /* forward declarations */
 static char *cdfs_match(am_opts *fo);
-static int cdfs_fmount(mntfs *mf);
-static int cdfs_fumount(mntfs *mf);
+static int cdfs_mount(am_node *am, mntfs *mf);
+static int cdfs_umount(am_node *am, mntfs *mf);
 
 /*
  * Ops structure
@@ -65,17 +64,20 @@ am_ops cdfs_ops =
   "cdfs",
   cdfs_match,
   0,				/* cdfs_init */
-  amfs_auto_fmount,
-  cdfs_fmount,
-  amfs_auto_fumount,
-  cdfs_fumount,
-  amfs_error_lookuppn,
+  cdfs_mount,
+  cdfs_umount,
+  amfs_error_lookup_child,
+  amfs_error_mount_child,
   amfs_error_readdir,
   0,				/* cdfs_readlink */
   0,				/* cdfs_mounted */
   0,				/* cdfs_umounted */
-  find_amfs_auto_srvr,
-  FS_MKMNT | FS_UBACKGROUND | FS_AMQINFO
+  amfs_generic_find_srvr,
+  0,				/* cdfs_get_wchan */
+  FS_MKMNT | FS_UBACKGROUND | FS_AMQINFO,	/* nfs_fs_flags */
+#ifdef HAVE_FS_AUTOFS
+  AUTOFS_CDFS_FS_FLAGS,
+#endif /* HAVE_FS_AUTOFS */
 };
 
 
@@ -89,10 +91,8 @@ cdfs_match(am_opts *fo)
     plog(XLOG_USER, "cdfs: no source device specified");
     return 0;
   }
-#ifdef DEBUG
   dlog("CDFS: mounting device \"%s\" on \"%s\"",
        fo->opt_dev, fo->opt_fs);
-#endif /* DEBUG */
 
   /*
    * Determine magic cookie to put in mtab
@@ -102,11 +102,11 @@ cdfs_match(am_opts *fo)
 
 
 static int
-mount_cdfs(char *dir, char *fs_name, char *opts)
+mount_cdfs(char *mntdir, char *fs_name, char *opts, int on_autofs)
 {
   cdfs_args_t cdfs_args;
   mntent_t mnt;
-  int genflags, cdfs_flags;
+  int genflags, cdfs_flags, retval;
 
   /*
    * Figure out the name of the file system type.
@@ -120,13 +120,13 @@ mount_cdfs(char *dir, char *fs_name, char *opts)
    * Fill in the mount structure
    */
   memset((voidp) &mnt, 0, sizeof(mnt));
-  mnt.mnt_dir = dir;
+  mnt.mnt_dir = mntdir;
   mnt.mnt_fsname = fs_name;
   mnt.mnt_type = MNTTAB_TYPE_CDFS;
   mnt.mnt_opts = opts;
 
 #if defined(MNT2_CDFS_OPT_DEFPERM) && defined(MNTTAB_OPT_DEFPERM)
-  if (hasmntopt(&mnt, MNTTAB_OPT_DEFPERM))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_DEFPERM))
 # ifdef MNT2_CDFS_OPT_DEFPERM
     cdfs_flags |= MNT2_CDFS_OPT_DEFPERM;
 # else /* not MNT2_CDFS_OPT_DEFPERM */
@@ -135,34 +135,38 @@ mount_cdfs(char *dir, char *fs_name, char *opts)
 #endif /* defined(MNT2_CDFS_OPT_DEFPERM) && defined(MNTTAB_OPT_DEFPERM) */
 
 #if defined(MNT2_CDFS_OPT_NODEFPERM) && defined(MNTTAB_OPT_NODEFPERM)
-  if (hasmntopt(&mnt, MNTTAB_OPT_NODEFPERM))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_NODEFPERM))
     cdfs_flags |= MNT2_CDFS_OPT_NODEFPERM;
 #endif /* MNTTAB_OPT_NODEFPERM */
 
 #if defined(MNT2_CDFS_OPT_NOVERSION) && defined(MNTTAB_OPT_NOVERSION)
-  if (hasmntopt(&mnt, MNTTAB_OPT_NOVERSION))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_NOVERSION))
     cdfs_flags |= MNT2_CDFS_OPT_NOVERSION;
 #endif /* defined(MNT2_CDFS_OPT_NOVERSION) && defined(MNTTAB_OPT_NOVERSION) */
 
 #if defined(MNT2_CDFS_OPT_RRIP) && defined(MNTTAB_OPT_RRIP)
-  if (hasmntopt(&mnt, MNTTAB_OPT_RRIP))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_RRIP))
     cdfs_flags |= MNT2_CDFS_OPT_RRIP;
 #endif /* defined(MNT2_CDFS_OPT_RRIP) && defined(MNTTAB_OPT_RRIP) */
 #if defined(MNT2_CDFS_OPT_NORRIP) && defined(MNTTAB_OPT_NORRIP)
-  if (hasmntopt(&mnt, MNTTAB_OPT_NORRIP))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_NORRIP))
     cdfs_flags |= MNT2_CDFS_OPT_NORRIP;
 #endif /* defined(MNT2_CDFS_OPT_NORRIP) && defined(MNTTAB_OPT_NORRIP) */
 
 #if defined(MNT2_CDFS_OPT_GENS) && defined(MNTTAB_OPT_GENS)
-  if (hasmntopt(&mnt, MNTTAB_OPT_GENS))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_GENS))
     cdfs_flags |= MNT2_CDFS_OPT_GENS;
 #endif /* defined(MNT2_CDFS_OPT_GENS) && defined(MNTTAB_OPT_GENS) */
 #if defined(MNT2_CDFS_OPT_EXTATT) && defined(MNTTAB_OPT_EXTATT)
-  if (hasmntopt(&mnt, MNTTAB_OPT_EXTATT))
+  if (amu_hasmntopt(&mnt, MNTTAB_OPT_EXTATT))
     cdfs_flags |= MNT2_CDFS_OPT_EXTATT;
 #endif /* defined(MNT2_CDFS_OPT_EXTATT) && defined(MNTTAB_OPT_EXTATT) */
 
   genflags = compute_mount_flags(&mnt);
+#ifdef HAVE_FS_AUTOFS
+  if (on_autofs)
+    genflags |= autofs_compute_mount_flags(&mnt);
+#endif /* HAVE_FS_AUTOFS */
 
 #ifdef HAVE_CDFS_ARGS_T_FLAGS
   cdfs_args.flags = cdfs_flags;
@@ -176,10 +180,6 @@ mount_cdfs(char *dir, char *fs_name, char *opts)
   cdfs_args.iso_pgthresh = hasmntval(&mnt, MNTTAB_OPT_PGTHRESH);
 #endif /* HAVE_CDFS_ARGS_T_ISO_PGTHRESH */
 
-#ifdef HAVE_CDFS_ARGS_T_FSPEC
-  cdfs_args.fspec = fs_name;
-#endif /* HAVE_CDFS_ARGS_T_FSPEC */
-
 #ifdef HAVE_CDFS_ARGS_T_NORRIP
   /* XXX: need to provide norrip mount opt */
   cdfs_args.norrip = 0;		/* use Rock-Ridge Protocol extensions */
@@ -190,19 +190,26 @@ mount_cdfs(char *dir, char *fs_name, char *opts)
   cdfs_args.ssector = 0;	/* use 1st session on disk */
 #endif /* HAVE_CDFS_ARGS_T_SSECTOR */
 
+#ifdef HAVE_CDFS_ARGS_T_FSPEC
+  cdfs_args.fspec = fs_name;
+#endif /* HAVE_CDFS_ARGS_T_FSPEC */
+
   /*
    * Call generic mount routine
    */
-  return mount_fs(&mnt, genflags, (caddr_t) &cdfs_args, 0, type, 0, NULL, mnttab_file_name);
+  retval = mount_fs(&mnt, genflags, (caddr_t) &cdfs_args, 0, type, 0, NULL, mnttab_file_name, on_autofs);
+
+  return retval;
 }
 
 
 static int
-cdfs_fmount(mntfs *mf)
+cdfs_mount(am_node *am, mntfs *mf)
 {
+  int on_autofs = mf->mf_flags & MFF_ON_AUTOFS;
   int error;
 
-  error = mount_cdfs(mf->mf_mount, mf->mf_info, mf->mf_mopts);
+  error = mount_cdfs(mf->mf_mount, mf->mf_info, mf->mf_mopts, on_autofs);
   if (error) {
     errno = error;
     plog(XLOG_ERROR, "mount_cdfs: %m");
@@ -213,7 +220,9 @@ cdfs_fmount(mntfs *mf)
 
 
 static int
-cdfs_fumount(mntfs *mf)
+cdfs_umount(am_node *am, mntfs *mf)
 {
-  return UMOUNT_FS(mf->mf_mount, mnttab_file_name);
+  int unmount_flags = (mf->mf_flags & MFF_ON_AUTOFS) ? AMU_UMOUNT_AUTOFS : 0;
+
+  return UMOUNT_FS(mf->mf_mount, mnttab_file_name, unmount_flags);
 }
