@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: amq.c,v 1.7.2.11 2005/01/03 20:56:12 ezk Exp $
+ * File: am-utils/amq/amq.c
  *
  */
 
@@ -46,19 +45,6 @@
  * Automounter query tool
  */
 
-#ifndef lint
-char copyright[] = "\
-@(#)Copyright (c) 1997-2005 Erez Zadok\n\
-@(#)Copyright (c) 1990 Jan-Simon Pendry\n\
-@(#)Copyright (c) 1990 Imperial College of Science, Technology & Medicine\n\
-@(#)Copyright (c) 1990 The Regents of the University of California.\n\
-@(#)All rights reserved.\n";
-#if __GNUC__ < 2
-static char rcsid[] = "$Id: amq.c,v 1.7.2.11 2005/01/03 20:56:12 ezk Exp $";
-static char sccsid[] = "%W% (Berkeley) %G%";
-#endif /* __GNUC__ < 2 */
-#endif /* not lint */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif /* HAVE_CONFIG_H */
@@ -116,7 +102,7 @@ show_mti(amq_mount_tree *mt, enum show_opt e, int *mwid, int *dwid, int *twid)
   case Full:
     {
       struct tm *tp = localtime((time_t *) &mt->mt_mounttime);
-      printf("%-*.*s %-*.*s %-*.*s %s\n\t%-5d %-7d %-6d %-7d %-7d %-6d %02d/%02d/%02d %02d:%02d:%02d\n",
+      printf("%-*.*s %-*.*s %-*.*s %s\n\t%-5d %-7d %-6d %-7d %-7d %-6d %02d/%02d/%04d %02d:%02d:%02d\n",
 	     *dwid, *dwid,
 	     *mt->mt_directory ? mt->mt_directory : "/",	/* XXX */
 	     *twid, *twid,
@@ -132,8 +118,8 @@ show_mti(amq_mount_tree *mt, enum show_opt e, int *mwid, int *dwid, int *twid)
 	     mt->mt_readlink,
 	     mt->mt_statfs,
 
-	     tp->tm_year > 99 ? tp->tm_year - 100 : tp->tm_year,
 	     tp->tm_mon + 1, tp->tm_mday,
+	     tp->tm_year < 1900 ? tp->tm_year + 1900 : tp->tm_year,
 	     tp->tm_hour, tp->tm_min, tp->tm_sec);
     }
   break;
@@ -141,7 +127,7 @@ show_mti(amq_mount_tree *mt, enum show_opt e, int *mwid, int *dwid, int *twid)
   case Stats:
     {
       struct tm *tp = localtime((time_t *) &mt->mt_mounttime);
-      printf("%-*.*s %-5d %-7d %-6d %-7d %-7d %-6d %02d/%02d/%02d %02d:%02d:%02d\n",
+      printf("%-*.*s %-5d %-7d %-6d %-7d %-7d %-6d %02d/%02d/%02d %02d:%02d:%04d\n",
 	     *dwid, *dwid,
 	     *mt->mt_directory ? mt->mt_directory : "/",	/* XXX */
 
@@ -152,8 +138,8 @@ show_mti(amq_mount_tree *mt, enum show_opt e, int *mwid, int *dwid, int *twid)
 	     mt->mt_readlink,
 	     mt->mt_statfs,
 
-	     tp->tm_year > 99 ? tp->tm_year - 100 : tp->tm_year,
 	     tp->tm_mon + 1, tp->tm_mday,
+	     tp->tm_year < 1900 ? tp->tm_year + 1900 : tp->tm_year,
 	     tp->tm_hour, tp->tm_min, tp->tm_sec);
     }
   break;
@@ -181,7 +167,7 @@ show_mti(amq_mount_tree *mt, enum show_opt e, int *mwid, int *dwid, int *twid)
  * Display a pwd data
  */
 static void
-show_pwd(amq_mount_tree *mt, char *path, int *flag)
+show_pwd(amq_mount_tree *mt, char *path, size_t l, int *flag)
 {
   int len;
 
@@ -189,13 +175,13 @@ show_pwd(amq_mount_tree *mt, char *path, int *flag)
     len = strlen(mt->mt_mountpoint);
     if (NSTREQ(path, mt->mt_mountpoint, len) &&
 	!STREQ(mt->mt_directory, mt->mt_mountpoint)) {
-      char buf[MAXPATHLEN+1];
-      strcpy(buf, mt->mt_directory);
-      strcat(buf, &path[len]);
-      strcpy(path, buf);
+      char buf[MAXPATHLEN+1];	/* must be same size as 'path' */
+      xstrlcpy(buf, mt->mt_directory, sizeof(buf));
+      xstrlcat(buf, &path[len], sizeof(buf));
+      xstrlcpy(path, buf, l);
       *flag = 1;
     }
-    show_pwd(mt->mt_next, path, flag);
+    show_pwd(mt->mt_next, path, l, flag);
     mt = mt->mt_child;
   }
 }
@@ -565,7 +551,7 @@ Usage: %s [-fmpsvwHTU] [-h hostname] [-l log_file|\"syslog\"]\n\
       mt = mlp->amq_mount_tree_list_val[i];
       while (1) {
 	flag = 0;
-	show_pwd(mt, path, &flag);
+	show_pwd(mt, path, sizeof(path), &flag);
 	if (!flag) {
 	  printf("%s\n", path);
 	  break;
