@@ -77,7 +77,8 @@ static int numfds = 0;
 static int bind_works = 1;
 
 
-static void hash_init(void)
+static void
+hash_init(void)
 {
   int i;
   struct rlimit rlim;
@@ -98,7 +99,8 @@ static void hash_init(void)
 }
 
 
-static void hash_insert(int fd, am_node *mp)
+static void
+hash_insert(int fd, am_node *mp)
 {
   if (hash[fd] != 0)
     plog(XLOG_ERROR, "file descriptor %d already in the hash", fd);
@@ -109,7 +111,8 @@ static void hash_insert(int fd, am_node *mp)
 }
 
 
-static void hash_delete(int fd)
+static void
+hash_delete(int fd)
 {
   int i;
 
@@ -637,7 +640,7 @@ autofs_mount_fs(am_node *mp, mntfs *mf)
 
  out:
   if (target2)
-    free(target2);
+    XFREE(target2);
 
   if (err)
     return errno;
@@ -778,10 +781,10 @@ autofs_mount_failed(am_node *mp)
 
 
 void
-autofs_get_opts(char *opts, autofs_fh_t *fh)
+autofs_get_opts(char *opts, size_t l, autofs_fh_t *fh)
 {
-  sprintf(opts, "fd=%d,minproto=%d,maxproto=%d",
-	  fh->kernelfd, AUTOFS_MIN_VERSION, AUTOFS_MAX_VERSION);
+  xsnprintf(opts, l, "fd=%d,minproto=%d,maxproto=%d",
+	    fh->kernelfd, AUTOFS_MIN_VERSION, AUTOFS_MAX_VERSION);
 }
 
 
