@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: checkmount_svr4.c,v 1.3.2.5 2005/01/03 20:56:12 ezk Exp $
+ * File: am-utils/conf/checkmount/checkmount_svr4.c
  *
  */
 
@@ -92,9 +91,9 @@ fixmount_check_mount(char *host, struct in_addr hostaddr, char *path)
 
     /* swap files never show up in mtab, only root fs */
     if ((swap = strstr(path, "swap"))) {
-      strncpy(swap, "root", 4);
+      strncpy(swap, "root", 4);	/* this should NOT use xstrlcpy  */
       found = fixmount_check_mount(host, hostaddr, path);
-      strncpy(swap, "swap", 4);
+      strncpy(swap, "swap", 4);	/* this should NOT use xstrlcpy  */
     }
   }
   return found;
