@@ -36,14 +36,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mount_aix.c,v 1.4.2.8 2005/01/03 20:56:12 ezk Exp $
+ * File: am-utils/conf/mount/mount_aix.c
  *
  */
 
 /*
- * AIX 3 Mount helper
+ * AIX 5.x Mount helper
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,7 +63,7 @@ extern int vmount(struct vmount *vmount, int size);
 
 
 static int
-aix3_mkvp(char *p, int gfstype, int flags, char *object, char *stub, char *host, char *info, int info_size, char *args)
+aix5_mkvp(char *p, int gfstype, int flags, char *object, char *stub, char *host, char *info, int info_size, char *args)
 {
   struct vmount *vp = (struct vmount *) p;
 
@@ -96,33 +95,27 @@ aix3_mkvp(char *p, int gfstype, int flags, char *object, char *stub, char *host,
 
 
 /*
- * Map from conventional mount arguments
- * to AIX 3-style arguments.
+ * Map from conventional mount arguments to AIX 3,x style arguments.
+ * But we avoid all the messy BIS stuff for AIX 5.x
  */
 int
 mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_opts)
 {
   char buf[4096];
   int size, ret;
-  int real_size = sizeof(nfs_args_t); /* size passed to aix3_mkvp() */
-  char *real_args = data;	/* args passed to aix3_mkvp() */
+  int real_size = sizeof(nfs_args_t); /* size passed to aix5_mkvp() */
+  char *real_args = data;	/* args passed to aix5_mkvp() */
   char *host, *rfs, *idx;
   int aix_type = type;
 #ifdef HAVE_FS_NFS3
   struct nfs_args v2args;
   nfs_args_t *v3args = (nfs_args_t *) data;
-#ifdef MOUNT_TYPE_NFS3_BIS
-  struct aix42_nfs_args_bis v3args_bis;
-#endif /* MOUNT_TYPE_NFS3_BIS */
 #endif /* HAVE_FS_NFS3 */
 
 #ifdef DEBUG
   dlog("mount_aix3: fsname %s, dir %s, type %d", fsname, dir, type);
 #endif /* DEBUG */
 
-#ifdef MOUNT_TYPE_NFS3_BIS
- retry_ibm_stupid_service_pack:
-#endif /* MOUNT_TYPE_NFS3_BIS */
   switch (aix_type) {
 
   case MOUNT_TYPE_NFS:
@@ -133,11 +126,9 @@ mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_o
      * then I must copy the arguments from the v3 nfs_args to the v2 one.
      */
     memmove((voidp) &v2args.addr, (voidp) &v3args->addr, sizeof(struct sockaddr_in));
-    /*     v2args.u0 = v3args->u0; */
-    /*     v2args.proto = v3args->proto; */
     v2args.hostname = v3args->hostname;
     v2args.netname = v3args->netname;
-    memmove(v2args.fh.x, ((fhandle_t *)v3args->fh)->x, FHSIZE);
+    memmove((voidp) v2args.fh.x, v3args->fh, FHSIZE);
     v2args.flags = v3args->flags;
     v2args.wsize = v3args->wsize;
     v2args.rsize = v3args->rsize;
@@ -147,7 +138,6 @@ mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_o
     v2args.acregmax = v3args->acregmax;
     v2args.acdirmin = v3args->acdirmin;
     v2args.acdirmax = v3args->acdirmax;
-    /*     v2args.u14 = v3args->u14; */
     v2args.pathconf = v3args->pathconf;
 
     /* now set real_* stuff */
@@ -155,35 +145,6 @@ mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_o
     real_args = (char *) &v2args;
 
   case MOUNT_TYPE_NFS3:
-#ifdef MOUNT_TYPE_NFS3_BIS
-  case MOUNT_TYPE_NFS3_BIS:
-    /* just fall through */
-    if (aix_type == MOUNT_TYPE_NFS3_BIS) {
-#ifdef DEBUG
-      dlog("mount_aix3: creating alternate nfs3_args structure");
-#endif /* DEBUG */
-      memmove((voidp) &v3args_bis.addr, (voidp) &v3args->addr, sizeof(struct sockaddr_in));
-      v3args_bis.u0 = v3args->u0;
-      v3args_bis.proto = v3args->proto;
-      v3args_bis.hostname = v3args->hostname;
-      v3args_bis.netname = v3args->netname;
-      v3args_bis.fh = v3args->fh;
-      v3args_bis.flags = v3args->flags;
-      v3args_bis.wsize = v3args->wsize;
-      v3args_bis.rsize = v3args->rsize;
-      v3args_bis.timeo = v3args->timeo;
-      v3args_bis.retrans = v3args->retrans;
-      v3args_bis.acregmin = v3args->acregmin;
-      v3args_bis.acregmax = v3args->acregmax;
-      v3args_bis.acdirmin = v3args->acdirmin;
-      v3args_bis.acdirmax = v3args->acdirmax;
-      v3args_bis.u14 = v3args->u14;
-      v3args_bis.pathconf = v3args->pathconf;
-      /* now set real_* stuff */
-      real_size = sizeof(v3args_bis);
-      real_args = (char *) &v3args_bis;
-    }
-#endif /* MOUNT_TYPE_NFS3_BIS */
 #endif /* HAVE_FS_NFS3 */
 
     idx = strchr(fsname, ':');
@@ -197,7 +158,7 @@ mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_o
       host = strdup(am_get_hostname());
     }
 
-    size = aix3_mkvp(buf, type, flags, rfs, dir, host,
+    size = aix5_mkvp(buf, type, flags, rfs, dir, host,
 		     real_args, real_size, mnt_opts);
     XFREE(rfs);
     XFREE(host);
@@ -211,18 +172,15 @@ mount_aix3(char *fsname, char *dir, int flags, int type, void *data, char *mnt_o
     return EINVAL;
   }
 
+  /*
+   * XXX: Warning, if vmount() hangs your amd in AIX 5.1, it
+   * is because of a kernel bug in the NFS code.  Get a patch from IBM
+   * or upgrade to 5.2.
+   */
   ret = vmount((struct vmount *)buf, size);
   if (ret < 0) {
     plog(XLOG_ERROR, "mount_aix3: vmount failed with errno %d", errno);
-#ifdef MOUNT_TYPE_NFS3_BIS
-    if (aix_type == MOUNT_TYPE_NFS3 && errno == EINVAL) {
-      aix_type = MOUNT_TYPE_NFS3_BIS;
-#ifdef DEBUG
-      dlog("mount_aix3: retrying with alternate nfs3_args structure");
-#endif /* DEBUG */
-      goto retry_ibm_stupid_service_pack;
-    }
-#endif /* MOUNT_TYPE_NFS3_BIS */
+    perror ("vmount");
   }
   return ret;
 }
