@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mtab_aix.c,v 1.5.2.8 2005/03/15 03:27:29 ezk Exp $
+ * File: am-utils/conf/mtab/mtab_aix.c
  *
  */
 
@@ -59,9 +58,9 @@
  * appear to be available in <sys/vmount.h> on AIX 5.3, and possibly
  * earlier. Hence I commented this out.
  */
-#if 0
+#ifndef HAVE_EXTERN_MNTCTL
 extern int mntctl(int cmd, int size, voidp buf);
-#endif
+#endif /* not HAVE_EXTERN_MNTCTL */
 
 
 static mntent_t *
