@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mtab_isc3.c,v 1.3.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/mtab/mtab_isc3.c
  *
  */
 
@@ -103,6 +102,7 @@ lockmnttab(void)
 void
 unlock_mntlist(void)
 {
+  dlog("unlock_mntlist: releasing");
   unlockmnttab();
 }
 
@@ -115,20 +115,16 @@ mnt_dup(mntent_t *mp)
   mntent_t *new_mp = ALLOC(mntent_t);
   char nullcpy[128];
 
-  strncpy(nullcpy, mp->mt_dev, 32);
-  nullcpy[32] = '\0';
+  xstrlcpy(nullcpy, mp->mt_dev, 32);
   new_mp->mnt_fsname = strdup(nullcpy);
 
-  strncpy(nullcpy, mp->mt_filsys, 32);
-  nullcpy[32] = '\0';
+  xstrlcpy(nullcpy, mp->mt_filsys, 32);
   new_mp->mnt_dir = strdup(nullcpy);
 
-  strncpy(nullcpy, mp->mt_fstyp, 16);
-  nullcpy[16] = '\0';
+  xstrlcpy(nullcpy, mp->mt_fstyp, 16);
   new_mp->mnt_type = strdup(nullcpy);
 
-  strncpy(nullcpy, mp->mt_mntopts, 64);
-  nullcpy[64] = '\0';
+  xstrlcpy(nullcpy, mp->mt_mntopts, 64);
   new_mp->mnt_opts = strdup(nullcpy);
 
   new_mp->mnt_freq = 0;
@@ -147,18 +143,14 @@ mtab_of(mntent_t *mnt)
 {
   static mntent_t mt;
 
-  memset(mt.mt_dev, '\0', 32);
-  strncpy(mt.mt_dev, mnt->mnt_fsname, 32);
-  memset(mt.mt_filsys, '\0', 32);
-  strncpy(mt.mt_filsys, mnt->mnt_dir, 32);
+  xstrlcpy(mt.mt_dev, mnt->mnt_fsname, 32);
+  xstrlcpy(mt.mt_filsys, mnt->mnt_dir, 32);
 
   mt.mt_ro_flg = mnt->mnt_ro;
   mt.mt_time = mnt->mnt_time;
 
-  memset(mt.mt_fstyp, '\0', 16);
-  strncpy(mt.mt_fstyp, mnt->mnt_type, 16);
-  memset(mt.mt_mntopts, '\0', 64);
-  strncpy(mt.mt_mntopts, mnt->mnt_opts, 64);
+  xstrlcpy(mt.mt_fstyp, mnt->mnt_type, 16);
+  xstrlcpy(mt.mt_mntopts, mnt->mnt_opts, 64);
 
   return &mt;
 }
