@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_freebsd3.h,v 1.5.2.8 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_freebsd3.h
  *
  */
 
@@ -55,6 +54,13 @@
 # include <nfs/nfs.h>
 #endif /* HAVE_NFS_NFS_H */
 #ifdef	HAVE_UFS_UFS_UFSMOUNT_H
+# ifdef HAVE_UFS_UFS_EXTATTR_H
+/*
+ * Define a dummy struct ufs_extattr_per_mount, which is used in struct
+ * ufsmount in <ufs/ufs/ufsmount.h>.
+ */
+struct ufs_extattr_per_mount;
+# endif /* HAVE_UFS_UFS_EXTATTR_H */
 # include <ufs/ufs/ufsmount.h>
 #endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
 
@@ -166,22 +172,16 @@ typedef writeargs nfswriteargs;
 # define MOUNT_NFS3	"nfs"	/* is this right? */
 # define MNTOPT_NFS3	"nfs"
 
+# ifndef HAVE_XDR_LOOKUP3RES
 /*
- * as of 3.0-RELEASE the nfs_fh3 that is defined in the system headers
- * (or the one generated by rpcgen) lacks the proper full definition,
- * listed below.  A special macro (m4/macros/struct_nfs_fh3.m4) searches
- * for this special name before other names.
+ * FreeBSD uses different field names than are defined on most other
+ * systems.
  */
-struct nfs_fh3_freebsd3 {
-  u_int fh3_length;
-  union nfs_fh3_u {
-    struct nfs_fh3_i {
-      fhandle_t fh3_i;
-    } nfs_fh3_i;
-    char data[NFS3_FHSIZE];
-  } fh3_u;
-};
-typedef struct nfs_fh3_freebsd3 nfs_fh3_freebsd3;
+#  define AMU_LOOKUP3RES_OK(x)		((x)->LOOKUP3res_u.resok)
+#  define AMU_LOOKUP3RES_FAIL(x)	((x)->LOOKUP3res_u.resfail)
+#  define AMU_LOOKUP3RES_FH_LEN(x)	(AMU_LOOKUP3RES_OK(x).object.data.data_len)
+#  define AMU_LOOKUP3RES_FH_DATA(x)	(AMU_LOOKUP3RES_OK(x).object.data.data_val)
+# endif /* not HAVE_XDR_LOOKUP3RES */
 
 #endif /* NFSMNT_NFSV3 */
 
