@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_hpux.h,v 1.4.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_hpux.h
  *
  */
 
@@ -65,6 +64,10 @@
 # include <rpcsvc/mount.h>
 #endif /* HAVE_RPCSVC_MOUNT_H */
 
+#ifdef HAVE_NETDB_H
+extern int h_errno;		/* missing from older hpux10 systems */
+#endif /* HAVE_NETDB_H */
+
 
 /*
  * Turn off NFS V.3 support to avoid confusing am-utils.
