@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_irix6.h,v 1.4.2.9 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_irix6.h
  *
  */
 
@@ -149,6 +148,7 @@
 # endif /* not MNTOPT_VERS */
 #endif /* MNTTYPE_NFS3 */
 
+#define AUTOFS_CONFTYPE "udp"
 
 /*
  * TYPEDEFS:
