@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_osf4.h,v 1.3.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_osf4.h
  *
  */
 
@@ -189,7 +188,7 @@ typedef struct nfswriteargs nfswriteargs;
 
 
 /*
- * EXTERNALS:
+ * EXTERNALS: (some are missing from system headers)
  */
 
 extern void *nfsproc_null_2_svc(void *, struct svc_req *);
@@ -210,6 +209,9 @@ extern nfsdiropres *nfsproc_mkdir_2_svc(nfscreateargs *, struct svc_req *);
 extern nfsstat *nfsproc_rmdir_2_svc(nfsdiropargs *, struct svc_req *);
 extern nfsreaddirres *nfsproc_readdir_2_svc(nfsreaddirargs *, struct svc_req *);
 extern nfsstatfsres *nfsproc_statfs_2_svc(struct nfssvcfh *, struct svc_req *);
+extern int plock(int op);
+extern const char *hstrerror(int err);
+extern int getmntinfo(struct statfs **mntbufp, int flags);
 
 extern bool_t xdr_nfsstat(XDR *, nfsstat*);
 extern bool_t xdr_ftype(XDR *, nfsftype*);
@@ -240,6 +242,9 @@ extern bool_t xdr_dirlist(XDR *, nfsdirlist*);
 extern bool_t xdr_readdirres(XDR *, nfsreaddirres*);
 extern bool_t xdr_statfsokres(XDR *, nfsstatfsokres*);
 extern bool_t xdr_statfsres(XDR *, nfsstatfsres*);
+extern bool_t xdr_exportnode (XDR *, exportnode*);
+extern bool_t xdr_groups (XDR *, groups*);
+
 
 
 /*
