@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_osf5.h,v 1.1.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_osf5.h
  *
  */
 
@@ -428,4 +427,20 @@ struct _statfsres {
   } sfr_u;
 };
 
+/*
+ **************************************************************************
+ * Tru64 5.1's autofs is not ported or tested yet...
+ * For now, undefine it or define dummy entries.
+ **************************************************************************
+ */
+#ifdef MNTTYPE_AUTOFS
+# undef MNTTYPE_AUTOFS
+#endif /* MNTTYPE_AUTOFS */
+#ifdef MNTTAB_TYPE_AUTOFS
+# undef MNTTAB_TYPE_AUTOFS
+#endif /* MNTTAB_TYPE_AUTOFS */
+#ifdef HAVE_FS_AUTOFS
+# undef HAVE_FS_AUTOFS
+#endif /* HAVE_FS_AUTOFS */
+
 #endif /* not _AMU_NFS_PROT_H */
