@@ -36,12 +36,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: fsi_data.h,v 1.3.2.5 2005/01/03 20:56:14 ezk Exp $
+ * File: am-utils/fsinfo/fsi_data.h
  *
  */
 
+#ifndef _FSI_DATA_H
+#define _FSI_DATA_H
+
 typedef struct auto_tree auto_tree;
 typedef struct automount automount;
 typedef struct dict dict;
@@ -233,3 +235,4 @@ struct ioloc {
   int i_line;
   char *i_file;
 };
+#endif /* not _FSI_DATA_H */
