@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: amu.h,v 1.3.2.5 2005/01/03 20:56:15 ezk Exp $
+ * File: am-utils/libamu/amu.h
  *
  */
 
@@ -75,4 +74,6 @@ extern amq_mount_info_list *amqproc_getmntfs_1(voidp argp, CLIENT *rqstp);
 extern int *amqproc_mount_1(voidp argp, CLIENT *rqstp);
 extern amq_string *amqproc_getvers_1(voidp argp, CLIENT *rqstp);
 
+extern long get_server_pid(void);
+
 #endif /* not _AMU_H */
