@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: misc_rpc.c,v 1.4.2.7 2005/01/03 20:56:15 ezk Exp $
+ * File: am-utils/libamu/misc_rpc.c
  *
  */
 
@@ -93,7 +92,7 @@ pickup_rpc_reply(voidp pkt, int len, voidp where, XDRPROC_T_TYPE where_xdr)
   memset((voidp) &reply_msg, 0, sizeof(reply_msg));
   memset((voidp) &reply_xdr, 0, sizeof(reply_xdr));
 
-  reply_msg.acpted_rply.ar_results.where = (caddr_t) where;
+  reply_msg.acpted_rply.ar_results.where = where;
   reply_msg.acpted_rply.ar_results.proc = where_xdr;
 
   xdrmem_create(&reply_xdr, pkt, len, XDR_DECODE);
