@@ -49,9 +49,10 @@
 
 
 /* ensure that mount table options are delimited by a comma */
-#define append_opts(old, new) { \
-	if (*(old) != '\0') strcat(old, ","); \
-	strcat(old, new); }
+#define append_opts(old, l, new) { \
+	if (*(old) != '\0') \
+	  xstrlcat(old, ",", l); \
+	xstrlcat(old, new, l); }
 
 /*
  * Standard mount flags
@@ -163,6 +164,7 @@ mount_fs(mntent_t *mnt, int flags, caddr_t mnt_data, int retry, MTYPE_TYPE type,
   int error = 0;
 #ifdef MOUNT_TABLE_ON_FILE
   char *zopts = NULL, *xopts = NULL;
+  size_t l;
 #endif /* MOUNT_TABLE_ON_FILE */
   char *mnt_dir = 0;
 
@@ -229,12 +231,13 @@ again:
    * Allocate memory for options:
    *        dev=..., vers={2,3}, proto={tcp,udp}
    */
-  zopts = (char *) xmalloc(strlen(mnt->mnt_opts) + 48);
+  l = strlen(mnt->mnt_opts) + 48;
+  zopts = (char *) xmalloc(l);
 
   /* copy standard options */
   xopts = mnt->mnt_opts;
 
-  strcpy(zopts, xopts);
+  xstrlcpy(zopts, xopts, l);
 
 # ifdef MNTTAB_OPT_DEV
   {
@@ -243,12 +246,12 @@ again:
     if (lstat(mnt_dir, &stb) == 0) {
       char optsbuf[48];
       if (sizeof(stb.st_dev) == 2) /* e.g. SunOS 4.1 */
-	sprintf(optsbuf, "%s=%04lx",
-		MNTTAB_OPT_DEV, (u_long) stb.st_dev & 0xffff);
+	xsnprintf(optsbuf, sizeof(optsbuf), "%s=%04lx",
+		  MNTTAB_OPT_DEV, (u_long) stb.st_dev & 0xffff);
       else			/* e.g. System Vr4 */
-	sprintf(optsbuf, "%s=%08lx",
-		MNTTAB_OPT_DEV, (u_long) stb.st_dev);
-      append_opts(zopts, optsbuf);
+	xsnprintf(optsbuf, sizeof(optsbuf), "%s=%08lx",
+		  MNTTAB_OPT_DEV, (u_long) stb.st_dev);
+      append_opts(zopts, l, optsbuf);
     }
   }
 # endif /* MNTTAB_OPT_DEV */
@@ -261,8 +264,9 @@ again:
    if (nfs_version == NFS_VERSION3 &&
        hasmntval(mnt, MNTTAB_OPT_VERS) != NFS_VERSION3) {
      char optsbuf[48];
-     sprintf(optsbuf, "%s=%d", MNTTAB_OPT_VERS, NFS_VERSION3);
-     append_opts(zopts, optsbuf);
+     xsnprintf(optsbuf, sizeof(optsbuf),
+	       "%s=%d", MNTTAB_OPT_VERS, NFS_VERSION3);
+     append_opts(zopts, l, optsbuf);
    }
 # endif /* defined(HAVE_FS_NFS3) && defined(MNTTAB_OPT_VERS) */
 
@@ -273,8 +277,8 @@ again:
    */
   if (nfs_proto && !amu_hasmntopt(mnt, MNTTAB_OPT_PROTO)) {
     char optsbuf[48];
-    sprintf(optsbuf, "%s=%s", MNTTAB_OPT_PROTO, nfs_proto);
-    append_opts(zopts, optsbuf);
+    xsnprintf(optsbuf, sizeof(optsbuf), "%s=%s", MNTTAB_OPT_PROTO, nfs_proto);
+    append_opts(zopts, l, optsbuf);
   }
 # endif /* MNTTAB_OPT_PROTO */
 
@@ -296,8 +300,9 @@ again:
 # ifdef HAVE_MNTENT_T_MNT_TIME
 #  ifdef HAVE_MNTENT_T_MNT_TIME_STRING
   {				/* allocate enough space for a long */
-    char *str = (char *) xmalloc(13 * sizeof(char));
-    sprintf(str, "%ld", time((time_t *) NULL));
+    size_t l = 13 * sizeof(char);
+    char *str = (char *) xmalloc(l);
+    xsnprintf(str, l, "%ld", time((time_t *) NULL));
     mnt->mnt_time = str;
   }
 #  else /* not HAVE_MNTENT_T_MNT_TIME_STRING */
@@ -846,8 +851,8 @@ get_hex_string(u_int len, const char *fhdata)
   memset(&arr[0], 0, (64 * sizeof(short int)));
   memcpy(&arr[0], &fhdata[0], len);
   for (i=0; i<len/sizeof(unsigned short int); i++) {
-    sprintf(str, "%04x", ntohs(arr[i]));
-    strcat(buf, str);
+    xsnprintf(str, sizeof(str), "%04x", ntohs(arr[i]));
+    xstrlcat(buf, str, sizeof(buf));
   }
   return buf;
 }
