@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: strcasecmp.c,v 1.3.2.5 2005/01/03 20:56:15 ezk Exp $
+ * File: am-utils/libamu/strcasecmp.c
  *
  */
 
@@ -54,8 +53,8 @@
 int
 strcasecmp(const char *s1, const char *s2)
 {
-  const char *cp1 = s1;
-  const char *cp2 = s2;
+  const unsigned char *cp1 = (const unsigned char *)s1;
+  const unsigned char *cp2 = (const unsigned char *)s2;
 
   while (tolower(*cp1) == tolower(*cp2++))
     if (*cp1++ == '\0')
