@@ -38,7 +38,7 @@
  * SUCH DAMAGE.
  *
  *
- * $Id: strerror.c,v 1.2.2.4 2005/01/03 20:56:15 ezk Exp $
+ * File: am-utils/libamu/strerror.c
  *
  */
 
@@ -58,7 +58,7 @@ strerror(int errnum)
 #ifdef HAVE_EXTERN_SYS_ERRLIST
   if (errnum < 0 || errnum >= (sizeof(sys_errlist) >> 2)) {
     static char errstr[30];
-    sprintf(errstr, "Unknown error #%d", errnum);
+    xsnprintf(errstr, sizeof(errstr), "Unknown error #%d", errnum);
     return errstr;
   }
   return sys_errlist[error];
